@@ -2,7 +2,7 @@ from django.db import models
 from django.utils.translation import ugettext_lazy as _
 import conf
 import datetime
-from xadrpy.router.models import ViewRoute, RouteTranslation
+from xadrpy.router.models import RouteTranslation, Route
 from ckeditor.fields import RichTextField
 import logging
 from xadrpy.access.models import OwnedModel
@@ -15,10 +15,11 @@ from django.core.urlresolvers import reverse, get_resolver, NoReverseMatch,\
 from xadrpy.vendor import trackback
 from django.contrib.sites.models import Site
 from django.http import Http404
+from xadrpy.contrib.pages.xtensions import PageApplication
 
 logger = logging.getLogger("Pages")
 
-class Page(ViewRoute, OwnedModel):
+class Page(Route, OwnedModel):
     comments_enabled = models.BooleanField(default=False, verbose_name = _("Comments enabled"), db_index=True)
     comments_unlocked = models.BooleanField(default=False, verbose_name = _("Comments locked"), db_index=True)
     view_count = models.PositiveIntegerField(default=0, verbose_name=_("View count"))
@@ -35,16 +36,10 @@ class Page(ViewRoute, OwnedModel):
         db_table = "xadrpy_pages_page"
 
     def get_view_name(self):
-        return self.view_name or self.default_view_name or conf.DEFAULT_VIEW
+        return conf.DEFAULT_VIEW
 
-    def get_urls(self, kwargs={}):
-        if self.app:
-            return self.app.get_urls(kwargs)
-        kwargs.update({'route': self.id})
-        slash = ""
-        if settings.APPEND_SLASH:
-            slash = "/"
-        return [url(self.get_translated_regex(slash=slash), self.get_view_name(), kwargs=kwargs, name=self.name)]
+    def get_application_class(self):
+        return PageApplication 
 
     def get_content_pages(self):
         return conf.PAGE_BREAK_RE.split(self.content) 
@@ -62,9 +57,9 @@ class Page(ViewRoute, OwnedModel):
         return conf.DEFAULT_TEMPLATE
 
     def get_absolute_url(self):
-        if self.app:
+        if self.app and hasattr(self.app, "get_absolute_url"):
             return self.app.get_absolute_url()
-        return reverse(self.get_view_name(), kwargs={'route': self.id})
+        return reverse(self.get_view_name(), kwargs={'route_id': self.id})
     
     def can_render(self):
         if not self.enabled or not self.published:
